@@ -25,7 +25,8 @@
 #endif
 
 #include <glib/gi18n.h>
-#include <gdk/gdk.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 
 G_BEGIN_DECLS
 
@@ -35,23 +36,25 @@ G_BEGIN_DECLS
 #define MOUSETWEAKS_DBUS_IFACE "org.gnome.Mousetweaks"
 #define MOUSETWEAKS_DBUS_PATH  "/org/gnome/Mousetweaks"
 
-#define MT_GCONF_HOME "/desktop/gnome/accessibility/mouse"
-#define OPT_THRESHOLD MT_GCONF_HOME "/threshold"
-#define OPT_SSC       MT_GCONF_HOME "/delay_enable"
-#define OPT_SSC_T     MT_GCONF_HOME "/delay_time"
-#define OPT_DWELL     MT_GCONF_HOME "/dwell_enable"
-#define OPT_DWELL_T   MT_GCONF_HOME "/dwell_time"
-#define OPT_CTW       MT_GCONF_HOME "/dwell_show_ctw"
-#define OPT_MODE      MT_GCONF_HOME "/dwell_mode"
-#define OPT_G_SINGLE  MT_GCONF_HOME "/dwell_gesture_single"
-#define OPT_G_DOUBLE  MT_GCONF_HOME "/dwell_gesture_double"
-#define OPT_G_DRAG    MT_GCONF_HOME "/dwell_gesture_drag"
-#define OPT_G_RIGHT   MT_GCONF_HOME "/dwell_gesture_secondary"
-#define OPT_STYLE     MT_GCONF_HOME "/button_layout"
-#define OPT_ANIMATE   MT_GCONF_HOME "/animate_cursor"
+/* GSettings */
+#define MT_SCHEMA_ID                "org.gnome.mousetweaks"
 
-#define GNOME_MOUSE_DIR "/desktop/gnome/peripherals/mouse"
-#define GNOME_MOUSE_ORIENT GNOME_MOUSE_DIR "/left_handed"
+#define KEY_DWELL_TIME              "dwell-time"
+#define KEY_DWELL_THRESHOLD         "dwell-threshold"
+#define KEY_DWELL_MODE              "dwell-mode"
+#define KEY_DWELL_GESTURE_SINGLE    "dwell-gesture-single"
+#define KEY_DWELL_GESTURE_DOUBLE    "dwell-gesture-double"
+#define KEY_DWELL_GESTURE_DRAG      "dwell-gesture-drag"
+#define KEY_DWELL_GESTURE_SECONDARY "dwell-gesture-secondary"
+#define KEY_SSC_TIME                "ssc-time"
+#define KEY_CTW_VISIBLE             "ctw-visible"
+#define KEY_CTW_STYLE               "ctw-style"
+#define KEY_ANIMATE_CURSOR          "animate-cursor"
+
+#define GSD_MOUSE_SCHEMA_ID         "org.gnome.settings-daemon.peripherals.mouse"
+
+#define KEY_DWELL_ENABLED           "dwell-click-enabled"
+#define KEY_SSC_ENABLED             "secondary-click-enabled"
 
 enum
 {
@@ -85,8 +88,16 @@ typedef enum
     MT_MESSAGE_LOGOUT
 } MtMessageType;
 
+Display *    mt_common_get_xdisplay      (void);
+
+void         mt_common_xtrap_push        (void);
+void         mt_common_xtrap_pop         (void);
+
+GdkScreen *  mt_common_get_screen        (void);
+
 void         mt_common_show_help         (GdkScreen     *screen,
                                           guint32        timestamp);
+
 gint         mt_common_show_dialog       (const gchar   *primary,
                                           const gchar   *secondary,
                                           MtMessageType  type);
