@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007-2008 Gerd Kohlberger <lowfi@chello.at>
+ * Copyright © 2007-2010 Gerd Kohlberger <gerdko gmail com>
  *
  * This file is part of Mousetweaks.
  *
@@ -20,20 +20,13 @@
 #ifndef __MT_CTW_H__
 #define __MT_CTW_H__
 
-#include "mt-main.h"
-
 G_BEGIN_DECLS
 
-gboolean    mt_ctw_init               (MTClosure *mt,
-				       gint       x,
-				       gint       y);
-GtkWidget * mt_ctw_get_window         (MTClosure *mt);
-void        mt_ctw_set_clicktype      (MTClosure *mt,
-				       guint      ct);
-void        mt_ctw_update_sensitivity (MTClosure *mt);
-void        mt_ctw_update_visibility  (MTClosure *mt);
-void        mt_ctw_update_style       (MTClosure *mt,
-				       gint       style);
+gboolean        mt_ctw_init               (gint x, gint y);
+
+void            mt_ctw_fini               (void);
+
+GtkWidget *     mt_ctw_get_window         (void);
 
 G_END_DECLS
 
